.. :changelog:

History
-------

0.1.20 (02-03-2016)
~~~~~~~~~~~~~~~~~~~

* Released to public with documentation at g2gtools.readthedocs.org


0.1.0 (02-09-2015)
~~~~~~~~~~~~~~~~~~

* Started github repository